

========================================================
geometries
========================================================


.. toctree::
    :maxdepth: 10

    ./BoxBufferGeometry_autogen.rst
    ./BoxGeometry_autogen.rst
    ./CircleBufferGeometry_autogen.rst
    ./CircleGeometry_autogen.rst
    ./ConeGeometry_autogen.rst
    ./CylinderBufferGeometry_autogen.rst
    ./CylinderGeometry_autogen.rst
    ./DodecahedronGeometry_autogen.rst
    ./EdgesGeometry_autogen.rst
    ./ExtrudeGeometry_autogen.rst
    ./IcosahedronGeometry_autogen.rst
    ./LatheBufferGeometry_autogen.rst
    ./LatheGeometry_autogen.rst
    ./OctahedronGeometry_autogen.rst
    ./ParametricGeometry_autogen.rst
    ./PlaneBufferGeometry_autogen.rst
    ./PlaneGeometry_autogen.rst
    ./PolyhedronGeometry_autogen.rst
    ./RingBufferGeometry_autogen.rst
    ./RingGeometry_autogen.rst
    ./ShapeGeometry_autogen.rst
    ./SphereBufferGeometry_autogen.rst
    ./SphereGeometry_autogen.rst
    ./TetrahedronGeometry_autogen.rst
    ./TextGeometry_autogen.rst
    ./TorusBufferGeometry_autogen.rst
    ./TorusGeometry_autogen.rst
    ./TorusKnotBufferGeometry_autogen.rst
    ./TorusKnotGeometry_autogen.rst
    ./TubeGeometry_autogen.rst
    ./WireframeGeometry_autogen.rst
